==> ugene_40.1+dfsg.orig.tar.xz: ugene-40.1/src/corelibs/U2Algorithm/src/util_msa_consensus/MSAConsensusAlgorithmRegistry.h <==
/**
 * UGENE - Integrated Bioinformatics Tools.
 * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
 * http://ugene.net
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA 02110-1301, USA.
 */

#ifndef _U2_MSA_CONSENSUS_ALGORITHM_REGISTRY_H_
#define _U2_MSA_CONSENSUS_ALGORITHM_REGISTRY_H_

#include <QStringList>

#include "MSAConsensusAlgorithm.h"

namespace U2 {

class MSAConsensusAlgorithm;

class U2ALGORITHM_EXPORT MSAConsensusAlgorithmRegistry : public QObject {
    Q_OBJECT

public:
    MSAConsensusAlgorithmRegistry(QObject *p = nullptr);

    ~MSAConsensusAlgorithmRegistry();

    MSAConsensusAlgorithmFactory *getAlgorithmFactory(const QString &algoId);

    void addAlgorithm(MSAConsensusAlgorithmFactory *algo);

    QStringList getAlgorithmIds() const;

    QList<MSAConsensusAlgorithmFactory *> getAlgorithmFactories() const {
        return algorithms.values();
    }

    QList<MSAConsensusAlgorithmFactory *> getAlgorithmFactories(ConsensusAlgorithmFlags flags) const;

private:
    QMap<QString, MSAConsensusAlgorithmFactory *> algorithms;
};

}  // namespace U2

#endif

==> ugene_49.1+dfsg.orig.tar.xz: ugene-49.1/src/corelibs/U2Algorithm/src/util_msa_consensus/MSAConsensusAlgorithmRegistry.h <==
/**
 * UGENE - Integrated Bioinformatics Tools.
 * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
 * http://ugene.net
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA 02110-1301, USA.
 */

#pragma once

#include <QStringList>

#include "MSAConsensusAlgorithm.h"

namespace U2 {

class MSAConsensusAlgorithm;

class U2ALGORITHM_EXPORT MSAConsensusAlgorithmRegistry : public QObject {
    Q_OBJECT

public:
    MSAConsensusAlgorithmRegistry(QObject* p = nullptr);

    ~MSAConsensusAlgorithmRegistry();

    MSAConsensusAlgorithmFactory* getAlgorithmFactory(const QString& algoId);

    void addAlgorithm(MSAConsensusAlgorithmFactory* algo);

    QStringList getAlgorithmIds() const;

    QList<MSAConsensusAlgorithmFactory*> getAlgorithmFactories() const {
        return algorithms.values();
    }

    QList<MSAConsensusAlgorithmFactory*> getAlgorithmFactories(ConsensusAlgorithmFlags flags) const;

private:
    QMap<QString, MSAConsensusAlgorithmFactory*> algorithms;
};

}  // namespace U2
